# LLMs to structure phenotypical manifestations

## Semantic Types originally extracted.
The specific STs extracted, along with their Type Unique Identifiers (TUIs), include T019 (“Congenital Abnormality”), T020 (“Acquired Abnormality”), T033 (“Finding”), T034 (“Laboratory or Test Result”), T041 (“Mental Process”), T046 (“Pathologic Function”), T047 (“Disease or Syndrom”), T048 (“Mental or Behavioral Dysfunction”), T049 (“Cell or Molecular Dysfunction”), T050 (“Experimental Model of Disease”), T059 (“Laboratory Procedure”), T060 (“Diagnostic Procedure”), T063 (“Molecular Biology Research Technique”), T073 (“Manufactured Object”), T170 (“Intellectual Product”), T184 (“Sign or Symptom”), T190 (“Anatomical Abnormality”), T191 (“Neoplastic Process”), and T201 (“Clinical Attribute”).


## Prompt engineering
We have used 6 different main prompts with different variations, which are hereunder described.

*  **Prompt 1: Zero-shot instruction**. It instructs the model to list observable characteristics classified by TUIs and STs, emphasizing the use of “phenotypic manifestations” to capture a broad range of symptoms beyond strict biomedical terms. A guided variation (**Zero-shot with guidance**) explicitly specifies the disease or condition in the text to enhance precision when identification is ambiguous, incorporating automation to extract condition names dynamically.

*  **Prompt 2: Entity dictionary**. It employs an entity dictionary, defined by TUIs and STs, with variations designed to assess the impact of dictionary detail and task framing. The base prompt focuses on identifying entities using the full dictionary, including detailed TUIs and STs descriptions. **Entity dictionary with guidance** adds the specific condition as seen in Prompt 1. **Entity dictionary simplified** simplifies the task by omitting the detailed TUI descriptions, reducing the dictionary’s complexity. **Entity dictionary simplified with guidance** is a combination of the two previous ones. Entity dictionary plus manifestations adds “manifestations” to the list of entities to be extracted, expanding the task scope. **Entity dictionary optimized by ChatGPT** extends the base Prompt 2 but with formatting and optimizations suggested by ChatGPT.

*  **Prompt 3: One-shot learning + entity dictionary**. It builds upon the structure of Prompt 2, introducing one-shot learning to enhance entity extraction. This approach includes an explicit example in the “assistant” role, showing the expected output format to guide the model's responses. It also uses a detailed entity dictionary with long descriptions for TUIs and STs. **One-shot learning + entity dictionary simplified** replaces the detailed entity dictionary with a concise version, reducing complexity while maintaining the same input text and example output.

*  **Prompt 4: Self-explanation + entity dictionary**. It integrates self explanation with an entity dictionary to enhance Named Entity Extraction (NEE) by requiring the model to justify each entity’s classification into specific TUIs and STs. This approach improves comprehension, accuracy, and transparency by breaking down the task into detailed reasoning steps, thereby reducing errors and increasing trustworthiness. Research has demonstrated that self-explanation prompting consistently outperforms zero-shot techniques and matches or exceeds the effectiveness of few-shot prompts across various dialogue-centric tasks [1]. **Self-explanation + entity dictionary simplified** replaces the detailed entity dictionary with a concise version as before.

*  **Prompt 5: One-shot learning + self-reflection + entity dictionary**. It integrates one-shot learning, self-reflection, and an entity dictionary, resembling the PromptNER method [2]. It includes providing an entity dictionary for TUIs and STs, a single example of input-output text for guidance, and self-reflective reasoning to justify entity selection. Unlike Chain-of-Thought (CoT), this method emphasizes post-decision reflection rather than intermediate reasoning. Although it excludes explanations for non-selected entities, this prompt supports precise entity identification and classification by requiring rationale for each selection, enhancing interpretability and trustworthiness in results. **One-shot learning + self-reflection + entity dictionary simplified** uses a simplified entity dictionary version.

*  **Prompt 6: Prompt chaining a) entity extraction b) entity classification**. It leverages prompt chaining to extract and classify entities from text by dividing the task into two subtasks [3]. In Step A, the model extracts all terms related to a condition using a zero-shot approach. In Step B, the extracted entities are classified into predefined categories based on a dictionary, assigning “Other” to uncategorized terms. Mismatched counts require reruns. Variants include using a simplified dictionary for classification or explicitly extracting as in previous prompts and classifying “manifestations” to emphasize phenotypical details.


## References
[1] H. Gao et al., “Self-Explanation Prompting Improves Dialogue Understanding in Large Language Models,” Sep. 22, 2023, arXiv: arXiv:2309.12940. doi: 10.48550/arXiv.2309.12940.

[2] D. Ashok and Z. C. Lipton, “PromptNER: Prompting For Named Entity Recognition,” Jun. 20, 2023, arXiv: arXiv:2305.15444. doi: 10.48550/arXiv.2305.15444.

[3] T. Wu et al., “PromptChainer: Chaining Large Language Model Prompts through Visual Programming,” Mar. 13, 2022, arXiv: arXiv:2203.06566. doi: 10.48550/arXiv.2203.06566.